#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-JUtvzm8HMHi9kUbsVznHBT
key:                  resource-pool-0.2.3.2-JUtvzm8HMHi9kUbsVznHBT
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  892a8be8dbce0003bee4ac3caa377ce7
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-JUtvzm8HMHi9kUbsVznHBT
depends:
    base-4.18.2.1 hashable-1.4.7.0-3I1JJMFn7WVBoCbELVuec1
    monad-control-1.0.3.1-CvSzPldK4ciIr3GPTO2wnc stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6.1-1m5v1p2gPuJ9ksxxBl2y4K
    vector-0.13.2.0-KEJu75twlkr1fQ5agH441G

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

